@@ -330,7 +330,7 @@ void AB_SelectBackendDialog_Fini(GWEN_DIALOG *dlg) {
 
 
 int AB_SelectBackendDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender) {
-  DBG_ERROR(0, "Activated: %s", sender);
+  DBG_NOTICE(0, "Activated: %s", sender);
   if (strcasecmp(sender, "okButton")==0)
     return GWEN_DialogEvent_ResultAccept;
   else if (strcasecmp(sender, "abortButton")==0)
