@@ -1046,7 +1046,7 @@ int AB_SetupDialog_DelAccount(GWEN_DIALOG *dlg) {
 
 
 int AB_SetupDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender) {
-  DBG_ERROR(0, "Activated: %s", sender);
+  DBG_NOTICE(0, "Activated: %s", sender);
   if (strcasecmp(sender, "closeButton")==0)
     return GWEN_DialogEvent_ResultAccept;
   else if (strcasecmp(sender, "editUserButton")==0)
