@@ -1191,10 +1191,14 @@ AH_JOB *AH_Job_Tan_new(AB_USER *u, int process, int jobVersion) {
   AH_JOB_TAN *aj;
   GWEN_DB_NODE *dbArgs;
   GWEN_DB_NODE *dbParams;
+  const char *s;
 
+  DBG_INFO(AQHBCI_LOGDOMAIN, "Looking for TAN job in version %d", jobVersion);
   j=AH_Job_new("JobTan", u, 0, jobVersion);
-  if (!j)
-    return 0;
+  if (!j) {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "TAN job in version %d not found", jobVersion);
+    return NULL;
+  }
 
   GWEN_NEW_OBJECT(AH_JOB_TAN, aj);
   GWEN_INHERIT_SETDATA(AH_JOB, AH_JOB_TAN, j, aj,
@@ -1214,6 +1218,12 @@ AH_JOB *AH_Job_Tan_new(AB_USER *u, int process, int jobVersion) {
   if (process==1 || process==2)
     GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "moreTans", "N");
+
+  /* set tanmedium id (if any) */
+  s=AH_User_GetTanMediumId(u);
+  if (s && *s)
+    AH_Job_Tan_SetTanMediumId(j, s);
+
   return j;
 }
 
