@@ -113,6 +113,7 @@ void GWENHYWFAR_CB AO_EditUserDialog_FreeData(void *bp, void *p) {
   free(xdlg->appVer);
   free(xdlg->headerVer);
   free(xdlg->clientUid);
+  free(xdlg->securityType);
 
   GWEN_FREE_OBJECT(xdlg);
 }
@@ -599,6 +600,7 @@ void AO_EditUserDialog_Init(GWEN_DIALOG *dlg) {
     s="102";
   GWEN_Dialog_SetCharProperty(dlg, "wiz_headerver_edit", GWEN_DialogProperty_Value, 0, s, 0);
 
+  xdlg->flags=AO_User_GetFlags(xdlg->user);
 
   /* read width */
   i=GWEN_DB_GetIntValue(dbPrefs, "dialog_width", 0, -1);
@@ -853,6 +855,7 @@ int AO_EditUserDialog_FromGui(GWEN_DIALOG *dlg) {
   AO_User_SetAppVer(xdlg->user, xdlg->appVer);
   AO_User_SetHeaderVer(xdlg->user, xdlg->headerVer);
   AO_User_SetClientUid(xdlg->user, xdlg->clientUid);
+  AO_User_SetSecurityType(xdlg->user, xdlg->securityType);
 
   AO_User_SetServerAddr(xdlg->user, xdlg->url);
   AO_User_SetHttpVMajor(xdlg->user, xdlg->httpVMajor);
@@ -894,17 +897,33 @@ int AO_EditUserDialog_HandleActivatedSpecial(GWEN_DIALOG *dlg) {
 
   AO_OfxSpecialDialog_SetHttpVersion(dlg2, xdlg->httpVMajor, xdlg->httpVMinor);
   AO_OfxSpecialDialog_SetFlags(dlg2, xdlg->flags);
+  AO_OfxSpecialDialog_SetClientUid(dlg2, xdlg->clientUid);
+  AO_OfxSpecialDialog_SetSecurityType(dlg2, xdlg->securityType);
 
   rv=GWEN_Gui_ExecDialog(dlg2, 0);
   if (rv==0) {
     /* rejected */
+    DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "Rejected");
     GWEN_Dialog_free(dlg2);
     return GWEN_DialogEvent_ResultHandled;
   }
   else {
+    const char *s;
+
+    DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "Accepted");
     xdlg->httpVMajor=AO_OfxSpecialDialog_GetHttpVMajor(dlg2);
     xdlg->httpVMinor=AO_OfxSpecialDialog_GetHttpVMinor(dlg2);
     xdlg->flags=AO_OfxSpecialDialog_GetFlags(dlg2);
+
+    s=AO_OfxSpecialDialog_GetClientUid(dlg2);
+    free(xdlg->clientUid);
+    if (s) xdlg->clientUid=strdup(s);
+    else xdlg->clientUid=NULL;
+
+    s=AO_OfxSpecialDialog_GetSecurityType(dlg2);
+    free(xdlg->securityType);
+    if (s) xdlg->securityType=strdup(s);
+    else xdlg->securityType=NULL;
   }
 
   GWEN_Dialog_free(dlg2);
